export interface Cookie {
    name: string;
    value?: string;
    maxAge?: number;
    expires?: Date;
    path?: string;
    domain?: string;
    secure?: boolean;
    httpOnly?: boolean;
    sameSite?: boolean | 'strict' | 'lax';
    overwrite?: boolean;
}
export declare class Result {
    readonly status: number;
    readonly value?: unknown;
    readonly cookies?: Cookie[] | undefined;
    readonly headers?: Record<string, string> | undefined;
    protected constructor(status: number, value?: unknown, cookies?: Cookie[] | undefined, headers?: Record<string, string> | undefined);
}
export interface ResultOptionsWithValue {
    value?: unknown;
    cookies?: Cookie[];
    headers?: Record<string, string>;
}
/** Used primarily in data routes where we want to force a value and it not show up in the options */
export interface ResultOptionsNoValue {
    cookies?: Cookie[];
    headers?: Record<string, string>;
}
export declare class DataResult extends Result {
    private readonly __type;
    private constructor();
    static ok(options?: ResultOptionsWithValue): DataResult;
    static error(value: unknown, options?: ResultOptionsNoValue): DataResult;
    static notFound(options?: ResultOptionsNoValue): DataResult;
    static unauthorized(options?: ResultOptionsNoValue): DataResult;
}
export declare class ViewResult extends Result {
    private readonly __type;
    template?: string;
    redirectUrl?: string;
    private constructor();
    static ok(template: string, options?: ResultOptionsWithValue): ViewResult;
    static redirect(url: string, status?: 301 | 302, options?: ResultOptionsNoValue): ViewResult;
    static error(template: string, options?: ResultOptionsWithValue): ViewResult;
    static notFound(template: string, options?: ResultOptionsWithValue): ViewResult;
    static unauthorized(template: string, options?: ResultOptionsWithValue): ViewResult;
}
