"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Result {
    constructor(status, value, cookies, headers) {
        this.status = status;
        this.value = value;
        this.cookies = cookies;
        this.headers = headers;
    }
}
exports.Result = Result;
function ensureNoValueOnOptions(options) {
    if (!options) {
        return {};
    }
    const optionsWithValue = options;
    // Make sure no one is doing any funny business with types
    // Technically the ResultOptionsWithValue will cast to ResultOptionsNoValue
    // given all properties are optional. So this is explicitly setting value to undefined
    // in case it was set.
    optionsWithValue.value = undefined;
    return optionsWithValue;
}
class DataResult extends Result {
    constructor(status, options) {
        super(status, options === null || options === void 0 ? void 0 : options.value, options === null || options === void 0 ? void 0 : options.cookies, options === null || options === void 0 ? void 0 : options.headers);
        // dummy read to compile - see notes above
        this.__type;
    }
    static ok(options) {
        const status = (options === null || options === void 0 ? void 0 : options.value) ? 200 : 204;
        return new DataResult(status, options);
    }
    static error(value, options) {
        const optionsWithValue = options !== null && options !== void 0 ? options : {};
        optionsWithValue.value = value;
        return new DataResult(400, optionsWithValue);
    }
    static notFound(options) {
        const sanitized = ensureNoValueOnOptions(options);
        return new DataResult(404, sanitized);
    }
    static unauthorized(options) {
        const sanitized = ensureNoValueOnOptions(options);
        return new DataResult(401, sanitized);
    }
}
exports.DataResult = DataResult;
class ViewResult extends Result {
    constructor(status, template, redirectUrl, options) {
        super(status, options === null || options === void 0 ? void 0 : options.value, options === null || options === void 0 ? void 0 : options.cookies, options === null || options === void 0 ? void 0 : options.headers);
        // Dummy read to compile
        this.__type;
        this.template = template;
        this.redirectUrl = redirectUrl;
    }
    static ok(template, options) {
        return new ViewResult(200, template, undefined, options);
    }
    static redirect(url, status = 302, options) {
        const sanitized = ensureNoValueOnOptions(options);
        return new ViewResult(status, undefined, url, sanitized);
    }
    static error(template, options) {
        return new ViewResult(400, template, undefined, options);
    }
    static notFound(template, options) {
        return new ViewResult(404, template, undefined, options);
    }
    static unauthorized(template, options) {
        return new ViewResult(401, template, undefined, options);
    }
}
exports.ViewResult = ViewResult;
//# sourceMappingURL=result.js.map